# acedb

A lightweight Python library + CLI tool to easily connect to your PostgreSQL database with minimal setup.  

## ✨ Features
- `acedb login`: set up your database credentials once
- `acedb test-connection`: test your database connection
- Simple, secure storage of credentials (saved locally)
- Easy-to-use Python wrapper to get a connection anywhere in your code
